.. _debian:

Debian
======

This section documents all related to the debian package.


Dependencies
------------

* ``openvpn``
* ``python-pyside``
* ``python-crypto``
* ``python-setuptools``
* ``python-requests``
* ``python-openssl``

.. note::
   these need a version that is not found in the current debian stable or in ubuntu 12.04. 
   They will be packaged... soon.

* ``python-keyring``

For tests
^^^^^^^^^
* ``python-nose``, ``python-mock``, ``python-coverage``

